@@ -2,8 +2,8 @@
 
 ;; Author: Marty Hiatt <mousebot@disroot.org>
 ;; Copyright (C) 2024 Marty Hiatt <mousebot@disroot.org>
-;; Package-Version: 0.8
-;; Package-Revision: cef3fc2daefb
+;; Package-Version: 20250206.812
+;; Package-Revision: cce2dfe0ec2b
 ;; Package-Requires: ((emacs "28.1") (transient "0.5.0"))
 ;; Keywords: convenience, api, requests
 ;; URL: https://codeberg.org/martianh/tp.el
@@ -270,12 +270,7 @@ Values to send will not be JSON booleans, but plain strings.")
 
 (cl-defmethod transient-init-value ((obj tp-option))
   "Initialize the value of OBJ."
-  (let* ((prefix-val
-          ;; (transient-get-value))) ;; new transient (broken)
-          ;; (transient--get-extended-value))) (also broken)
-          ;; (oref transient--prefix value))) ;; old transient (broken)
-          ;; (transient-scope))) ;; doesn't work
-          tp-transient-settings)) ;; our variable (works?)
+  (let* ((prefix-val (oref transient--prefix value)))
     (oset obj value
           (tp-get-server-val obj prefix-val))))
 
@@ -391,14 +386,7 @@ We add the current value as initial input."
 The format of the value is a transient pair as a string, ie \"key=val\".
 Nil values will also match the empty string.
 OBJ is the object whose args are being checked."
-  (let* ((data ;; (transient-get-value)) ;; new transient (broken)
-          ;; (oref transient--prefix value)) ;; get from prefix (old, broken)
-          ;; get from self? (works if suffix initialized, but useless, as
-          ;; we need no just val but also key to check server val):
-          ;; (oref obj value))
-          ;; our variable (works, server value rather than current prefix
-          ;; state):
-          tp-transient-settings)
+  (let* ((data (oref transient--prefix value))
          (server-val (tp-get-server-val obj data))
          (server-str (if (and server-val
                               (symbolp server-val))
@@ -409,8 +397,7 @@ OBJ is the object whose args are being checked."
 (cl-defmethod tp-get-server-val ((obj tp-option) data)
   "Return the server value for OBJ from DATA.
 If OBJ's key has dotted notation, drill down into the alist. Currently
-only one level of nesting is supported.
-DATA is JSON data returned from the server."
+only one level of nesting is supported."
   ;; TODO: handle nested alist keys
   (let* ((key (oref obj alist-key))
          (split (split-string (symbol-name key) "\\.")))
